import sys
import unittest

sys.path.append(".")

# === unit tests ===
#from test_offline import *
#from test_stat import *
from test_twitter import *
#from test_wiki import *
# ==================


# logging
if __name__ == "__main__":
    import logging
    logging.basicConfig(level = logging.WARNING)

# run unittests
if __name__ == "__main__":
    unittest.main()